"use client"

import { DropdownMenuItem } from "@/components/ui/dropdown-menu"
import { useDeleteGweet } from "../hooks/use-delete-gweet"
import { IGweet } from "../types"

import { Icons } from "@/components/icons"
import { Button } from "@/components/ui/button"
import {
    Dialog,
    DialogContent,
    DialogDescription,
    DialogFooter,
    DialogHeader,
    DialogTitle,
    DialogTrigger,
} from "@/components/ui/dialog"
import { useRouter } from "next/navigation"

export const DeleteGweetModal = ({ gweet, props, forwardedRef }: { gweet: IGweet, props: any, forwardedRef: any }) => {
    const { triggerChildren, onSelect, onOpenChange, ...itemProps } = props
    const { isLoading, mutate, isSuccess } = useDeleteGweet()

    const router = useRouter()
    if (isSuccess) router.push("/home")

    return (
        <Dialog onOpenChange={onOpenChange}>
            <DialogTrigger asChild>
                <DropdownMenuItem
                    {...itemProps}
                    ref={forwardedRef}
                    onSelect={(event) => {
                        event.preventDefault()
                        onSelect && onSelect()
                    }}>
                    {triggerChildren}
                </DropdownMenuItem>
            </DialogTrigger>
            <DialogContent className="sm:max-w-[425px]">
                <DialogHeader>
                    <DialogTitle>Delete gweet?</DialogTitle>
                    <DialogDescription>
                        You are about to delete this gweet. This can&apos;t be undone and will be removed from your profile,
                        the timeline of any accounts that follow you, and from the search results.
                    </DialogDescription>
                </DialogHeader>
                <DialogFooter>
                    <Button
                        variant="destructive"
                        type="submit"
                        disabled={isLoading}
                        onClick={() => {
                            mutate({
                                gweetId: gweet?.id,
                            })
                        }}>
                        {isLoading && (
                            <Icons.spinner className="mr-2 h-4 w-4 animate-spin" />
                        )}
                        Delete
                    </Button>
                </DialogFooter>
            </DialogContent>
        </Dialog>
    )
}